# API Reference

Complete API documentation for all Prismo modules and classes.

```{toctree}
:maxdepth: 2

backends
core
solvers
materials
boundaries
sources
monitors
modes
analysis
io
optimization
geometry
utils
visualization
```
